
Introduction
------------

**BLADE** is a Python framework for benchmarking the Llm Assisted Design and
Evolution of algorithms.

**Key Features:**

- **Fast and simple**: BLADE is designed to be easy to use and fast to run.
- **Flexible**: BLADE is designed to be flexible and can be easily extended.
- **Scalable**: BLADE is designed to be scalable and can be run on a single machine or a cluster.
- **Open Source**: BLADE is open source and free to use.
